==> zio-aws-alexaforbusiness_3-5.17.104.2-sources.jar: zio/aws/alexaforbusiness/model/AddressBook.scala <==
package zio.aws.alexaforbusiness.model
import zio.ZIO
import zio.aws.alexaforbusiness.model.primitives.{
  AddressBookDescription,
  AddressBookName,
  Arn
}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class AddressBook(
    addressBookArn: Option[Arn] = None,
    name: Option[AddressBookName] = None,
    description: Option[AddressBookDescription] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.alexaforbusiness.model.AddressBook = {
    import AddressBook.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.alexaforbusiness.model.AddressBook
      .builder()
      .optionallyWith(
        addressBookArn.map(value => Arn.unwrap(value): java.lang.String)
      )(_.addressBookArn)
      .optionallyWith(
        name.map(value => AddressBookName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        description.map(value =>
          AddressBookDescription.unwrap(value): java.lang.String
        )
      )(_.description)
      .build()
  }
  def asReadOnly: zio.aws.alexaforbusiness.model.AddressBook.ReadOnly =
    zio.aws.alexaforbusiness.model.AddressBook.wrap(buildAwsValue())
}
object AddressBook {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.alexaforbusiness.model.AddressBook
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.alexaforbusiness.model.AddressBook =
      zio.aws.alexaforbusiness.model.AddressBook(
        addressBookArn.map(value => value),
        name.map(value => value),
        description.map(value => value)
      )
    def addressBookArn: Option[Arn]
    def name: Option[AddressBookName]
    def description: Option[AddressBookDescription]
    def getAddressBookArn: ZIO[Any, AwsError, Arn] =
      AwsError.unwrapOptionField("addressBookArn", addressBookArn)
    def getName: ZIO[Any, AwsError, AddressBookName] =
      AwsError.unwrapOptionField("name", name)
    def getDescription: ZIO[Any, AwsError, AddressBookDescription] =
      AwsError.unwrapOptionField("description", description)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.AddressBook
  ) extends zio.aws.alexaforbusiness.model.AddressBook.ReadOnly {
    override val addressBookArn: Option[Arn] = scala
      .Option(impl.addressBookArn())
      .map(value => zio.aws.alexaforbusiness.model.primitives.Arn(value))
    override val name: Option[AddressBookName] = scala
      .Option(impl.name())
      .map(value =>
        zio.aws.alexaforbusiness.model.primitives.AddressBookName(value)
      )
    override val description: Option[AddressBookDescription] = scala
      .Option(impl.description())
      .map(value =>
        zio.aws.alexaforbusiness.model.primitives.AddressBookDescription(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.AddressBook
  ): zio.aws.alexaforbusiness.model.AddressBook.ReadOnly = new Wrapper(impl)
}

==> zio-aws-alexaforbusiness_3-5.17.169.1-sources.jar: zio/aws/alexaforbusiness/model/AddressBook.scala <==
package zio.aws.alexaforbusiness.model
import zio.ZIO
import zio.aws.alexaforbusiness.model.primitives.{
  AddressBookDescription,
  AddressBookName,
  Arn
}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class AddressBook(
    addressBookArn: Optional[Arn] = Optional.Absent,
    name: Optional[AddressBookName] = Optional.Absent,
    description: Optional[AddressBookDescription] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.alexaforbusiness.model.AddressBook = {
    import AddressBook.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.alexaforbusiness.model.AddressBook
      .builder()
      .optionallyWith(
        addressBookArn.map(value => Arn.unwrap(value): java.lang.String)
      )(_.addressBookArn)
      .optionallyWith(
        name.map(value => AddressBookName.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(
        description.map(value =>
          AddressBookDescription.unwrap(value): java.lang.String
        )
      )(_.description)
      .build()
  }
  def asReadOnly: zio.aws.alexaforbusiness.model.AddressBook.ReadOnly =
    zio.aws.alexaforbusiness.model.AddressBook.wrap(buildAwsValue())
}
object AddressBook {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.alexaforbusiness.model.AddressBook
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.alexaforbusiness.model.AddressBook =
      zio.aws.alexaforbusiness.model.AddressBook(
        addressBookArn.map(value => value),
        name.map(value => value),
        description.map(value => value)
      )
    def addressBookArn: Optional[Arn]
    def name: Optional[AddressBookName]
    def description: Optional[AddressBookDescription]
    def getAddressBookArn: ZIO[Any, AwsError, Arn] =
      AwsError.unwrapOptionField("addressBookArn", addressBookArn)
    def getName: ZIO[Any, AwsError, AddressBookName] =
      AwsError.unwrapOptionField("name", name)
    def getDescription: ZIO[Any, AwsError, AddressBookDescription] =
      AwsError.unwrapOptionField("description", description)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.AddressBook
  ) extends zio.aws.alexaforbusiness.model.AddressBook.ReadOnly {
    override val addressBookArn: Optional[Arn] = zio.aws.core.internal
      .optionalFromNullable(impl.addressBookArn())
      .map(value => zio.aws.alexaforbusiness.model.primitives.Arn(value))
    override val name: Optional[AddressBookName] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value =>
        zio.aws.alexaforbusiness.model.primitives.AddressBookName(value)
      )
    override val description: Optional[AddressBookDescription] =
      zio.aws.core.internal
        .optionalFromNullable(impl.description())
        .map(value =>
          zio.aws.alexaforbusiness.model.primitives
            .AddressBookDescription(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.AddressBook
  ): zio.aws.alexaforbusiness.model.AddressBook.ReadOnly = new Wrapper(impl)
}
